@@ -65,7 +65,7 @@ public:
 };
 
 template<typename T, typename L, typename R>
-VEC< T, VVTIMES< T, L, R > > operator*(const VEC<T, L>& a, const VEC<T, R>& b) {
+inline VEC< T, VVTIMES< T, L, R > > operator*(const VEC<T, L>& a, const VEC<T, R>& b) {
 
   bool ismatrix_ = false;
   int nrows_ = 0;
@@ -140,7 +140,7 @@ public:
 };
 
 template<typename T, typename L, typename R>
-VEC< T, VSTIMES< T, L, R > > operator*(const VEC<T, L>& a, const R& b) {
+inline VEC< T, VSTIMES< T, L, R > > operator*(const VEC<T, L>& a, const R& b) {
   bool ismatrix_ = false;
   int nrows_ = 0;
   int ncols_ = 0;
@@ -201,7 +201,7 @@ public:
 
 
 template<typename T, typename L, typename R>
-VEC< T, SVTIMES< T, L, R > > operator*(const R& a, const VEC<T, L>&  b) {
+inline VEC< T, SVTIMES< T, L, R > > operator*(const R& a, const VEC<T, L>&  b) {
   bool ismatrix_ = false;
   int nrows_ = 0;
   int ncols_ = 0;
